%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

%global srcname markup

Name:           ocaml-%{srcname}
Version:        1.0.3
Release:        %mkrel 5
Summary:        Error-recovering streaming HTML5 and XML parsers for OCaml
Group:          Development/OCaml

License:        MIT
URL:            https://aantron.github.io/markup.ml/
Source0:        https://github.com/aantron/markup.ml/archive/%{version}/%{srcname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.02.0
BuildRequires:  ocaml-bisect-ppx-devel >= 2.0.0
BuildRequires:  ocaml-dune >= 2.7.0
BuildRequires:  ocaml-lwt-devel
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-ounit-devel
BuildRequires:  ocaml-uutf-devel >= 1.0.0

%description
Markup.ml is a pair of parsers implementing the HTML5 and XML
specifications, including error recovery.  Usage is simple, because each
parser is a function from byte streams to parsing signal streams.

In addition to being error-correcting, the parsers are:
- **streaming**: parsing partial input and emitting signals while more
  input is still being received;
- **lazy**: not parsing input unless you have requested the next parsing
  signal, so you can easily stop parsing part-way through a document;
- **non-blocking**: they can be used with Lwt, but still provide a
  straightforward synchronous interface for simple usage; and
- **one-pass**: memory consumption is limited since the parsers don't
  build up a document representation, nor buffer input beyond a small
  amount of lookahead.

The parsers detect character encodings automatically, and emit everything
in UTF-8.  The HTML parser understands SVG and MathML, in addition to
HTML5.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       ocaml-uutf-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%package        lwt
Summary:        Adapter between ocaml-markup and ocaml-lwt
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    lwt
This package contains an adapter between Markup.ml and Lwt.

%package        lwt-devel
Summary:        Development files for %{name}-lwt
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}-lwt%{?_isa} = %{version}-%{release}
Requires:       ocaml-bisect-ppx-devel%{?_isa}
Requires:       ocaml-lwt-devel%{?_isa}

%description    lwt-devel
The %{name}-lwt-devel package contains libraries and signature files for
developing applications that use %{name}-lwt.

%prep
%autosetup -n %{srcname}.ml-%{version} -p1

# The uchar package is a forward compatibility package for OCaml versions prior
# to 4.03.  We have a later OCaml in Fedora; uchar is in the standard library.
# Nothing in this package directly refers to uchar (only indirectly via uutf),
# so just remove the reference to it.
sed -i '/uchar/d' markup.opam

%build
%dune_build

%install
%dune_install -s

%check
%dune_check

%files -f .ofiles-markup
%doc README.md
%license LICENSE.md

%files devel -f .ofiles-markup-devel

%files lwt -f .ofiles-markup-lwt

%files lwt-devel -f .ofiles-markup-lwt-devel



%changelog
* Tue Jul 08 2025 umeabot <umeabot> 1.0.3-5.mga10
+ Revision: 2251455
- Mageia 10 Mass Rebuild

* Sun Apr 13 2025 pterjan <pterjan> 1.0.3-4.mga10
+ Revision: 2175425
- Rebuild for OCaml 5.3

* Sat Oct 15 2022 neoclust <neoclust> 1.0.3-3.mga9
+ Revision: 1896997
- Rebuild against new ocaml-base

* Fri May 20 2022 pterjan <pterjan> 1.0.3-2.mga9
+ Revision: 1859414
- Rebuild for OCaml 4.14

* Tue May 17 2022 pterjan <pterjan> 1.0.3-1.mga9
+ Revision: 1858481
- Update to 1.0.3

* Fri Oct 15 2021 tv <tv> 1.0.2-1.mga9
+ Revision: 1751510
- Version 1.0.2

* Thu Mar 25 2021 tv <tv> 1.0.0-1.mga9
+ Revision: 1709766
- 1.0.0

* Sun Jan 10 2021 pterjan <pterjan> 0.8.2-4.mga8
+ Revision: 1670775
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 0.8.2-3.mga8
+ Revision: 1551806
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 0.8.2-2.mga8
+ Revision: 1545755
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 0.8.2-1.mga8
+ Revision: 1485143
- imported package ocaml-markup


* Thu Jan 16 2020 Jerry James <loganjerry@gmail.com> - 0.8.2-2
- Add ocaml-uutf-devel R to -devel
- Add ocaml-bisect-ppx-devel R to -lwt-devel
- Build in parallel

* Fri Jan 10 2020 Jerry James <loganjerry@gmail.com> - 0.8.2-1
- Initial RPM
